@@ -1,5 +1,3 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-
 /*
  * gtkimmoduleime
  * Copyright (C) 2003 Takuro Ashie
@@ -19,7 +17,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: imime.c,v 1.3 2003/05/07 12:42:50 makeinu Exp $
+ * $Id: imime.c,v 1.11 2003/12/07 04:57:23 makeinu Exp $
  */
 
 #include <gtk/gtkimmodule.h>
@@ -27,42 +25,43 @@
 
 #include <string.h>
 
-static const GtkIMContextInfo ime_info = { 
-    "win32ime",    /* ID */
-    "Windows IME", /* Human readable name */
-    "gtk+",	       /* Translation domain */
-    "",            /* Dir for bindtextdomain (not strictly needed for "gtk+") */
-    "*",           /* Languages for which this module is the default */
+static const GtkIMContextInfo ime_info = {
+  "win32ime",
+  "Windows IME",
+  "gtk+",
+  "",
+  "*",
 };
 
 static const GtkIMContextInfo *info_list[] = {
-    &ime_info,
+  &ime_info,
 };
 
 void
-im_module_init (GTypeModule *module)
+im_module_init (GTypeModule * module)
 {
-    gtk_im_context_ime_register_type (module);
+  gtk_im_context_ime_register_type (module);
 }
 
-void 
+void
 im_module_exit (void)
 {
 }
 
-void 
-im_module_list (const GtkIMContextInfo ***contexts,
-                int                      *n_contexts)
+void
+im_module_list (const GtkIMContextInfo *** contexts, int *n_contexts)
 {
-    *contexts = info_list;
-    *n_contexts = G_N_ELEMENTS (info_list);
+  *contexts = info_list;
+  *n_contexts = G_N_ELEMENTS (info_list);
 }
 
 GtkIMContext *
-im_module_create (const gchar *context_id)
+im_module_create (const gchar * context_id)
 {
-    if (!strcmp (context_id, "win32ime"))
-        return gtk_im_context_ime_new();
-    else
-        return NULL;
+  g_return_val_if_fail (context_id, NULL);
+
+  if (!strcmp (context_id, "win32ime"))
+    return g_object_new (GTK_TYPE_IM_CONTEXT_IME, NULL);
+  else
+    return NULL;
 }
